@@ -10,7 +10,7 @@
 #if defined(JAS_CONFIGURE)
 
 /* This preprocessor symbol identifies the version of JasPer. */
-#define	JAS_VERSION "1.900.28"
+#define	JAS_VERSION "1.900.29"
 
 #define JAS_HAVE_FCNTL_H 1
 #undef JAS_HAVE_IO_H
@@ -22,6 +22,8 @@
 #define JAS_HAVE_GETTIMEOFDAY 1
 #define JAS_HAVE_GETRUSAGE 1
 
+#define JAS_HAVE_SNPRINTF	1
+
 #else
 
 /* We are not using a configure-based build. */
@@ -30,21 +32,25 @@
 #define JAS_VERSION "unknown"
 #define JAS_HAVE_FCNTL_H		1
 #define JAS_HAVE_IO_H			1
-#define JAS_HAVE_UNISTD_H		0
+#undef JAS_HAVE_UNISTD_H
 #define JAS_HAVE_WINDOWS_H		1
-#define JAS_HAVE_SYS_TIME_H		0
+#undef JAS_HAVE_SYS_TIME_H
 #define JAS_HAVE_SYS_TYPES_H	1
 #undef JAS_HAVE_GETTIMEOFDAY
 #undef JAS_HAVE_GETRUSAGE
 
+#undef JAS_HAVE_SNPRINTF
+
 // I don't think that this should be needed anymore.
-#if 0
+#if 1
 #ifndef __cplusplus
 #undef inline
 #define inline __inline
 #endif
 #endif
 
+#define ssize_t long long
+
 #endif
 
 #if !defined(JAS_DEC_DEFAULT_MAX_SAMPLES)
